import gsap from 'gsap';
import { PixiPlugin } from 'gsap/PixiPlugin';
import * as PIXI from 'pixi.js';

PIXI.settings.FILTER_RESOLUTION = window.devicePixelRatio || 1;
PixiPlugin.registerPIXI(PIXI);
gsap.registerPlugin(PixiPlugin);

export default class {
  constructor(selector, imageList) {
    this.isActive = false;
    this.el = document.querySelector(selector);
    this.resolution = this.getResolution;
    this.app = new PIXI.Application({
      width: this.resolution.x,
      height: this.resolution.y,
      transparent: true,
      resolution: window.devicePixelRatio || 1,
      autoResize: true,
      autoDensity: true,
      // antialias: true,
    });
    this.el.appendChild(this.app.view);

    this.imageList = [...imageList].map(el => {
      const mesh = new PIXI.SimplePlane(PIXI.Texture.from(el.src), 4, 3);
      this.app.stage.addChild(mesh);
      return mesh;
    });
  }

  get getResolution() {
    return {
      x: this.el.clientWidth,
      y: this.el.clientHeight
    }
  }
}
