const path = require('path');
const webpack = require('webpack');
const WebpackBuildNotifierPlugin = require('webpack-build-notifier');
const { merge } = require('webpack-merge');
const HtmlWebpackPlugin = require('html-webpack-plugin');

const mode = {
  dev: require('./webpack.dev.js'),
  prod: require('./webpack.prod.js')
};

// 開発 or 本番
const DEBUG = 0 ? true : false;

const config = {
  entry: {
    bundle: './src/js/app.js'
  },
  output: {
    filename: '[name].js'
  },
  resolve: {
    modules: [path.join(__dirname, 'node_modules')],
    extensions: ['.webpack.js', '.web.js', '.js'],
    alias: { '@': path.join(__dirname, 'src/js') }
  },
  plugins: [
    new WebpackBuildNotifierPlugin({
      sound: false,
    }),
    new HtmlWebpackPlugin({
      inject: 'head',
      template: './src/index.html'
    })
  ],
  optimization: {
    splitChunks: {
      cacheGroups: {
        vendor: {
          test: /(node_modules|src\/js\/lib)/,
          name: 'vendor',
          chunks: 'initial',
          enforce: true
        }
      }
    }
  },
  module: {
    rules: [
      {
        test: /\.js$/,
        exclude: /(node_modules)/,
        use: [
          {
            loader: "babel-loader",
            options: {
              presets: [
                ["@babel/preset-env", {
                  useBuiltIns: "usage",
                  corejs: 3
                }]
              ]
            }
          }
        ]
      },
      {
        test: /\.scss$/,
        use: [
          "style-loader",
          {
            loader: "css-loader",
            options: {
              url: true,
              sourceMap: DEBUG,
              importLoaders: 2
            }
          },
          {
            loader: "postcss-loader",
            options: {
              sourceMap: true,
              postcssOptions: {
                plugins: [
                  require("autoprefixer")({ grid: true })
                ]
              }
            }
          },
          {
            loader: "sass-loader",
            options: {
              sourceMap: DEBUG
            }
          },
        ]
      },
      {
        test: /\.css$/,
        use: [
          "style-loader",
          {
            loader: "css-loader",
            options: {
              url: false,
              sourceMap: DEBUG,
              importLoaders: 2
            }
          }
        ]
      },
      {
        test: /\.html$/i,
        loader: 'html-loader',
      },
      {
       test: /\.(gif|png|jpg|eot|wof|woff|ttf|svg)$/,
       // type: "asset/inline",
       loader: 'file-loader',
       options: {
         publicPath: './',
         name: '[path][name].[ext]',
       },
     },
    ],
  },
};

module.exports = DEBUG
  ? merge(config, mode.dev)
  : merge(config, mode.prod);
